==> lightdash_client_python-0.619.1-py3-none-any.whl: lightdash_client/api/content/update_pinned_items_order.py <==
from http import HTTPStatus
from typing import Any
from typing import Dict
from typing import List
from typing import Optional

import httpx

from ... import errors
from ...client import Client
from ...models.api_pinned_items import ApiPinnedItems
from ...models.update_pinned_item_order import UpdatePinnedItemOrder
from ...types import Response


def _get_kwargs(
    project_uuid: str,
    pinned_list_uuid: str,
    *,
    client: Client,
    json_body: List["UpdatePinnedItemOrder"],
) -> Dict[str, Any]:
    url = "{}/api/v1/projects/{projectUuid}/pinned-lists/{pinnedListUuid}/items/order".format(
        client.base_url, projectUuid=project_uuid, pinnedListUuid=pinned_list_uuid
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = []
    for json_body_item_data in json_body:
        json_body_item = json_body_item_data.to_dict()

        json_json_body.append(json_body_item)

    return {
        "method": "patch",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[ApiPinnedItems]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ApiPinnedItems.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[ApiPinnedItems]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_uuid: str,
    pinned_list_uuid: str,
    *,
    client: Client,
    json_body: List["UpdatePinnedItemOrder"],
) -> Response[ApiPinnedItems]:
    """Update pinned items order

    Args:
        project_uuid (str):
        pinned_list_uuid (str):
        json_body (List['UpdatePinnedItemOrder']): the new order of the pinned items

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApiPinnedItems]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        pinned_list_uuid=pinned_list_uuid,
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_uuid: str,
    pinned_list_uuid: str,
    *,
    client: Client,
    json_body: List["UpdatePinnedItemOrder"],
) -> Optional[ApiPinnedItems]:
    """Update pinned items order

    Args:
        project_uuid (str):
        pinned_list_uuid (str):
        json_body (List['UpdatePinnedItemOrder']): the new order of the pinned items

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApiPinnedItems
    """

    return sync_detailed(
        project_uuid=project_uuid,
        pinned_list_uuid=pinned_list_uuid,
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    project_uuid: str,
    pinned_list_uuid: str,
    *,
    client: Client,
    json_body: List["UpdatePinnedItemOrder"],
) -> Response[ApiPinnedItems]:
    """Update pinned items order

    Args:
        project_uuid (str):
        pinned_list_uuid (str):
        json_body (List['UpdatePinnedItemOrder']): the new order of the pinned items

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApiPinnedItems]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        pinned_list_uuid=pinned_list_uuid,
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_uuid: str,
    pinned_list_uuid: str,
    *,
    client: Client,
    json_body: List["UpdatePinnedItemOrder"],
) -> Optional[ApiPinnedItems]:
    """Update pinned items order

    Args:
        project_uuid (str):
        pinned_list_uuid (str):
        json_body (List['UpdatePinnedItemOrder']): the new order of the pinned items

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApiPinnedItems
    """

    return (
        await asyncio_detailed(
            project_uuid=project_uuid,
            pinned_list_uuid=pinned_list_uuid,
            client=client,
            json_body=json_body,
        )
    ).parsed

==> lightdash_client_python-0.1471.0-py3-none-any.whl: lightdash_client/api/content/update_pinned_items_order.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.api_pinned_items import ApiPinnedItems
from ...models.update_pinned_item_order import UpdatePinnedItemOrder
from ...types import UNSET, Response


def _get_kwargs(
    project_uuid: str,
    pinned_list_uuid: str,
    *,
    body: List["UpdatePinnedItemOrder"],
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "patch",
        "url": "/api/v1/projects/{projectUuid}/pinned-lists/{pinnedListUuid}/items/order".format(
            projectUuid=project_uuid,
            pinnedListUuid=pinned_list_uuid,
        ),
    }

    _body = []
    for body_item_data in body:
        body_item = body_item_data.to_dict()
        _body.append(body_item)

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[ApiPinnedItems]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ApiPinnedItems.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[ApiPinnedItems]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_uuid: str,
    pinned_list_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: List["UpdatePinnedItemOrder"],
) -> Response[ApiPinnedItems]:
    """Update pinned items order

    Args:
        project_uuid (str):
        pinned_list_uuid (str):
        body (List['UpdatePinnedItemOrder']): the new order of the pinned items

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApiPinnedItems]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        pinned_list_uuid=pinned_list_uuid,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_uuid: str,
    pinned_list_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: List["UpdatePinnedItemOrder"],
) -> Optional[ApiPinnedItems]:
    """Update pinned items order

    Args:
        project_uuid (str):
        pinned_list_uuid (str):
        body (List['UpdatePinnedItemOrder']): the new order of the pinned items

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApiPinnedItems
    """

    return sync_detailed(
        project_uuid=project_uuid,
        pinned_list_uuid=pinned_list_uuid,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_uuid: str,
    pinned_list_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: List["UpdatePinnedItemOrder"],
) -> Response[ApiPinnedItems]:
    """Update pinned items order

    Args:
        project_uuid (str):
        pinned_list_uuid (str):
        body (List['UpdatePinnedItemOrder']): the new order of the pinned items

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ApiPinnedItems]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        pinned_list_uuid=pinned_list_uuid,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_uuid: str,
    pinned_list_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: List["UpdatePinnedItemOrder"],
) -> Optional[ApiPinnedItems]:
    """Update pinned items order

    Args:
        project_uuid (str):
        pinned_list_uuid (str):
        body (List['UpdatePinnedItemOrder']): the new order of the pinned items

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ApiPinnedItems
    """

    return (
        await asyncio_detailed(
            project_uuid=project_uuid,
            pinned_list_uuid=pinned_list_uuid,
            client=client,
            body=body,
        )
    ).parsed
